@@ -90,13 +90,7 @@ KdeConnectConfig::KdeConnectConfig()
 
 QString KdeConnectConfig::name()
 {
-    QString username;
-    #ifdef Q_OS_WIN
-        username = QString::fromLatin1(qgetenv("USERNAME"));
-    #else
-        username = QString::fromLatin1(qgetenv("USER"));
-    #endif
-    QString defaultName = username + QStringLiteral("@") + QHostInfo::localHostName();
+    QString defaultName = QHostInfo::localHostName();
     QString name = d->m_config->value(QStringLiteral("name"), defaultName).toString();
     return name;
 }
@@ -109,7 +103,23 @@ void KdeConnectConfig::setName(const QString& name)
 
 QString KdeConnectConfig::deviceType()
 {
-    return QStringLiteral("desktop"); // TODO
+#ifdef SAILFISHOS
+    return QStringLiteral("phone");
+#else
+    const QByteArrayList platforms = qgetenv("PLASMA_PLATFORM").split(':');
+
+    if (platforms.contains("phone")) {
+        return QStringLiteral("phone");
+    } else if (platforms.contains("tablet")) {
+        return QStringLiteral("tablet");
+    } else if(platforms.contains("mediacenter")) {
+        return QStringLiteral("tv");
+    }
+
+    // TODO non-Plasma mobile platforms
+
+    return QStringLiteral("desktop");
+#endif
 }
 
 QString KdeConnectConfig::deviceId()
