@@ -15,21 +15,18 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 #ifndef KIOKDECONNECT_H
 #define KIOKDECONNECT_H
 
 #include <QObject>
-#include <QLoggingCategory>
 
 #include <kio/slavebase.h>
 
 #include "interfaces/dbusinterfaces.h"
 
-Q_DECLARE_LOGGING_CATEGORY(KDECONNECT_KIO)
-
 class KioKdeconnect : public QObject, public KIO::SlaveBase
 {
     Q_OBJECT
