@@ -19,7 +19,7 @@
  */
 
 #include "notification.h"
-#include "notification_debug.h"
+#include "plugin_notification_debug.h"
 
 #include <KNotification>
 #include <QtGlobal>
@@ -42,7 +42,7 @@ Notification::Notification(const NetworkPacket& np, const Device* device, QObjec
     , m_imagesDir()
     , m_device(device)
 {
-    //Make a own directory for each user so noone can see each others icons
+    //Make a own directory for each user so no one can see each others icons
     QString username;
     #ifdef Q_OS_WIN
         username = QString::fromLatin1(qgetenv("USERNAME"));
@@ -63,7 +63,7 @@ Notification::Notification(const NetworkPacket& np, const Device* device, QObjec
         if(!m_requestReplyId.isEmpty() && actionIndex == 1) {
             return;
         }
-        // Notification action idices start at 1
+        // Notification action indices start at 1
         Q_EMIT actionTriggered(m_internalId, m_actions[actionIndex - 1]);
     });
 }
@@ -105,13 +105,11 @@ void Notification::createKNotification(const NetworkPacket& np)
     QString escapedText = m_text.toHtmlEscaped();
     QString escapedTicker = m_ticker.toHtmlEscaped();
 
-#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 57, 0)
     if (NotificationServerInfo::instance().supportedHints().testFlag(NotificationServerInfo::X_KDE_DISPLAY_APPNAME)) {
         m_notification->setTitle(escapedTitle);
         m_notification->setText(escapedText);
         m_notification->setHint(QStringLiteral("x-kde-display-appname"), m_appName.toHtmlEscaped());
     } else {
-#endif
         m_notification->setTitle(m_appName.toHtmlEscaped());
 
         if (m_title.isEmpty() && m_text.isEmpty()) {
@@ -125,22 +123,9 @@ void Notification::createKNotification(const NetworkPacket& np)
         } else {
             m_notification->setText(escapedTitle + QStringLiteral(": ") + escapedText);
         }
-
-#if KNOTIFICATIONS_VERSION >= QT_VERSION_CHECK(5, 57, 0)
     }
 
     m_notification->setHint(QStringLiteral("x-kde-origin-name"), m_device->name());
-#endif
-
-    m_hasIcon = m_hasIcon && !m_payloadHash.isEmpty();
-
-    if (!m_hasIcon) {
-        applyNoIcon();
-        show();
-    } else {
-        m_iconPath = m_imagesDir.absoluteFilePath(m_payloadHash);
-        loadIcon(np);
-    }
 
     if (!m_requestReplyId.isEmpty()) {
         m_actions.prepend(i18n("Reply"));
@@ -148,6 +133,15 @@ void Notification::createKNotification(const NetworkPacket& np)
     }
 
     m_notification->setActions(m_actions);
+
+    m_hasIcon = m_hasIcon && !m_payloadHash.isEmpty();
+
+    if (!m_hasIcon) {
+        show();
+    } else {
+        m_iconPath = m_imagesDir.absoluteFilePath(m_payloadHash);
+        loadIcon(np);
+    }
 }
 
 void Notification::loadIcon(const NetworkPacket& np)
@@ -169,7 +163,6 @@ void Notification::loadIcon(const NetworkPacket& np)
             s_downloadsInProgress.remove(m_iconPath);
             if (fileTransferJob->error()) {
                 qCDebug(KDECONNECT_PLUGIN_NOTIFICATION) << "Error in FileTransferJob: " << fileTransferJob->errorString();
-                applyNoIcon();
             } else {
                 applyIcon();
             }
@@ -184,12 +177,6 @@ void Notification::applyIcon()
     m_notification->setPixmap(icon);
 }
 
-void Notification::applyNoIcon()
-{
-    //HACK The only way to display no icon at all is trying to load a non-existent icon
-    m_notification->setIconName(QStringLiteral("not_a_real_icon"));
-}
-
 void Notification::reply()
 {
     Q_EMIT replyRequested();
